@@ -9,9 +9,13 @@ from mcp_proxy_adapter.commands.base import Command
 from mcp_proxy_adapter.commands.result import CommandResult, SuccessResult, ErrorResult
 from mcp_proxy_adapter.commands.command_registry import registry
 from mcp_proxy_adapter.core.errors import (
-    MicroserviceError, CommandError, ValidationError, 
-    InvalidParamsError, NotFoundError, TimeoutError,
-    InternalError
+    MicroserviceError,
+    CommandError,
+    ValidationError,
+    InvalidParamsError,
+    NotFoundError,
+    TimeoutError,
+    InternalError,
 )
 
 # Экспортируем основные классы и функции для удобного использования
@@ -19,7 +23,7 @@ __all__ = [
     "__version__",
     "create_app",
     "Command",
-    "CommandResult", 
+    "CommandResult",
     "SuccessResult",
     "ErrorResult",
     "registry",
@@ -29,5 +33,5 @@ __all__ = [
     "InvalidParamsError",
     "NotFoundError",
     "TimeoutError",
-    "InternalError"
+    "InternalError",
 ]
