@@ -16,17 +16,11 @@ from mcp_proxy_adapter.api.app import create_app
 
 def main():
     """Main CLI entry point."""
-    print("MCP Proxy Adapter v6.2.21")
-    print("========================")
-    print()
-    print("Usage:")
-    print("  python -m mcp_proxy_adapter")
-    print("  # or")
-    print("  mcp-proxy-adapter")
-    print()
-    print("For more information, see:")
-    print("  https://github.com/maverikod/mcp-proxy-adapter#readme")
+    # Import and run the actual main function from main.py
+    from mcp_proxy_adapter.main import main as run_server
+
+    run_server()
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
